package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*@`!````(!T``#0```!8`@$`&````#0`(``)
M`"@`&@`9``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````R)8`
M`,B6```%```````!``$```#@_@``X/X!`.#^`0!X`@``C`(```8```````$`
M`@```.C^``#H_@$`Z/X!`!@!```8`0``!@````0````$````:`$``&@!``!H
M`0``)````"0````$````!`````0````@``$`(``"`"```@`@````(`````0`
M```$````4>5T9```````````````````````````!@````@```!2Y71DX/X`
M`.#^`0#@_@$`(`$``"`!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!0````#````1TY5`(N2@JFGYD+/+SV`X6/IOEC/?TE$0P```&``````
M`````````%D````*````)P```#X`````````/``````````]````/P```$0`
M```Z````6`````D````X````+0`````````O````&```````````````*0``
M`!P```!2`````P```%0```!=````4P```$\`````````````````````````
M2@```"0````"`````````$T````W`````````"@`````````0P```%P`````
M````$0```$````!!````2P```"8````J`````````%L````V````,0````T`
M````````0@```%X````'````.P```"(```!%````-````#,```!'````````
M```````````````````````````````````````````````````````(````
M```````````!`````````````````````````!(````,`````````!`````$
M````#@```%H````````````````````/``````````L````>````&@``````
M```5````%@````4``````````````!T```!,`````````"``````````(P``
M`%4`````````1@```````````````````!0`````````-0```$X`````````
M20`````````?````40```"L`````````5@``````````````.0```#(```!(
M`````````!<```!?```````````````N````````````````````````````
M```9````+````%`````P````(0``````````````)0``````````````!@``
M````````````&P```%<````3````$0```$4````(````"``````0$`0E0`2`
M*```!*"&`(2`@0`""R@%&#B`$D&*```(`````$4```!(````2P```$P```!4
M````50```%8`````````6````%D```!:````6P```%P```!?````````````
M``!NQ=\?SMY'+6M_FGPNQ9NV(/_D#M5DU'S9<5@<XD?&`4+ZUX>L2^/`NN.2
M?,+E/RSZH6Q@L@&+;YE/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+
M?ZF<F^"G`@IJ&IY0L=QK%*/@^TD`````````````````````>`(`````````
M````$@```)8"`````````````"(````2`@`````````````2````9@(`````
M````````$@````<"`````````````!(````0```````````````@````[@(`
M````````````$0```&<#`````````````!(```"(`@`````````````1````
M\@$`````````````$@```.D``````````````!(```#,`0`````````````2
M````T`(`````````````$@````H#`````````````!$```!-`0``````````
M```2`````0(`````````````$@```(<``````````````!(```"L`@``````
M```````2````Y```````````````$@```*0!`````````````!(```#"`@``
M```````````2````0@(`````````````$@```#\!`````````````!(```#&
M```````````````1````#0$`````````````$@```&,``````````````!8`
M``![`0`````````````2````.0(`````````````$@```/@"````````````
M`!(```"Z`0`````````````2````:`$`````````````$@```"$"````````
M`````!(```#K`0`````````````2````=`$`````````````$@```!L!````
M`````````!(````!```````````````@````M0$`````````````$@```(8!
M`````````````!$```"E`@`````````````2````5```````````````$@``
M`-P!`````````````!(```"6```````````````2````UP(`````````````
M$@```*(``````````````!(````T`0`````````````2````#`(`````````
M````$@```+,"`````````````!(```#Z```````````````2````CP(`````
M````````$@```$8``````````````!(```#N```````````````2````70$`
M````````````$@```-,``````````````!(```#)`@`````````````2````
M^@$`````````````$@```"@"`````````````!(```!V```````````````2
M````MP``````````````$@```"L!`````````````!(```#C`0``````````
M```2````P@$`````````````$@```%@"`````````````!(````L````````
M```````@````\`(`````````````$0```.@"`````````````!(```#3`0``
M```````````2````N@(`````````````$@```$H"`````````````!(```!P
M`P``T#P``#@!```2``T`G`,``!@S``!H!P``$@`-`',"``#0&@``4`(``!(`
M#0!$`P``#"8``"`````2``T`(`0``"PF```X`P``$@`-`%X$``"`.@``4`(`
M`!(`#0`,!```6`$"```````0`!<`@P,``&0I```X````$@`-`*D#```H4P``
M*`$``!(`#0#!`P``[%4```0````1``\`\`,``&P!`@``````$``7`!@$``#H
M)```2````!(`#0`M!```I#$``'0!```2``T`/P0``+0N``!\````$@`-`$T$
M```P+P``P````!(`#0"T`P`````"```````0`!0`D`,``)PI```X`0``$@`-
M`'P#``!8`0(``````!``%@#F`P``'``"``0````1`!0`N@,``"`=````````
M$@`-`%4$``"X4@``<````!(`#0"V`P`````"```````@`!0`50,``'0Q```P
M````$@`-`-`#```P)0``W````!(`#0`"!```4%0``$`!```2``T`E0$```0`
M`@``````$0`4`/4#``#4*@``X`,``!(`#0``7U]G;6]N7W-T87)T7U\`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?7V9P<V-R7W9A;'5E<P!?7W-T
M86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L
M;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!R
M;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T
M-C1?=&EM938T`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P
M<FEN=&9?8VAK`%]?;&EB8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S
M=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M
M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`7U]E<G)N;U]L;V-A
M=&EO;@!A8F]R=`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C
M:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!L9"UL:6YU
M>"YS;RXR`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B87-E;F%M90!P87)?9&ER
M;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`7TE/
M7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`&UY7W!A<E]P;`!?
M96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI
M=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A
M;@!P87)?9&EE`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"
M0U\R+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR`$=,24)#
M7S(N,S0``````@`#``0``@`#``$``P`#``,``P`#``,``P`%``$``P`!``,`
M`0`&``,``P`!``$``0`!``$``P`'``,``0`#``,``P`!``$``P`!``,``0`#
M``$``P`!``$``P`#``$``P`!``$``0`!``,``P`"``$``0`!``,``P`$``$`
M`P`#``,``P`$``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`V`P``$````"`````4:6D-```%`'0$
M`````````0`%`"P#```0`````````'(9:0D```<`?@0``!`````4:6D-```&
M`'0$```0````=!EI"0``!`"*!```$````!)I:0T```,`E@0``!````"TD98&
M```"`*`$````````X/X!`*4````<'@``Y/X!`*4```#('0``#``"`*4````,
M``(`'``"`*4```!`60``/!T```%'````````0!T```$$````````1!T```%!
M````````)`$"`*,"````````*`$"`*,&````````+`$"`*,)````````,`$"
M`*,.````````-`$"`*,/````````.`$"`*,8````````/`$"`)<:````````
M0`$"`*,D````````1`$"`*,F````````2`$"`*,P````````3`$"`*,Y````
M````4`$"`*,_````````5`$"`*-`````````3``"`*0!````````4``"`*0"
M````````5``"`*0#````````6``"`*0%````````7``"`*0(````````8``"
M`*0*````````9``"`*0+````````:``"`*0,````````;``"`*0-````````
M<``"`*00````````=``"`*01````````>``"`*02````````?``"`*03````
M````@``"`*04````````A``"`*05````````B``"`*06````````C``"`*07
M````````D``"`*09````````E``"`*0;````````F``"`*0<````````G``"
M`*0=````````H``"`*0>````````I``"`*0?````````J``"`*0@````````
MK``"`*0A````````L``"`*0B````````M``"`*0C````````N``"`*0D````
M````O``"`*0E````````P``"`*0G````````Q``"`*0H````````R``"`*0I
M````````S``"`*0J````````T``"`*0K````````U``"`*0L````````V``"
M`*0M````````W``"`*0N````````X``"`*0O````````Y``"`*0Q````````
MZ``"`*0R````````[``"`*0S````````\``"`*0T````````]``"`*0U````
M````^``"`*0V````````_``"`*0W``````````$"`*0X````````!`$"`*0Z
M````````"`$"`*0[````````#`$"`*0\````````$`$"`*0]````````%`$"
M`*0^````````&`$"`*1"````````'`$"`*1#````````(`$"`*1$````````
M`````````````````````````````````````,8O!\<&W.8O##PB3P70S@$8
M(0.-\VX$T0,!"0`&H`D`H.L!```!``!``P``"0`)``D`"0`)``D`"0`)``D`
M"0#C;R9/]F[V;`L`"0`%T`)@!B\#T`)@*T#V8`D`"0`)````````````!-#.
M`"M`"0#"4`/1*T#!4`D`"0`,``````````30S@`K0`D`PE`#T2M`P5`)``D`
M$`````P````$T,X`*T`)`,)0`]$K0,%0"0`)`!0````8````!-#.`"M`"0#"
M4`/1*T#!4`D`"0`8````)`````30S@`K0`D`PE`#T2M`P5`)``D`'````#``
M```$T,X`*T`)`,)0`]$K0,%0"0`)`"`````\````!-#.`"M`"0#"4`/1*T#!
M4`D`"0`D````2`````30S@`K0`D`PE`#T2M`P5`)``D`*````%0````$T,X`
M*T`)`,)0`]$K0,%0"0`)`"P```!@````!-#.`"M`"0#"4`/1*T#!4`D`"0`P
M````;`````30S@`K0`D`PE`#T2M`P5`)``D`-````'@````$T,X`*T`)`,)0
M`]$K0,%0"0`)`#@```"$````!-#.`"M`"0#"4`/1*T#!4`D`"0`\````D```
M``30S@`K0`D`PE`#T2M`P5`)``D`0````)P````$T,X`*T`)`,)0`]$K0,%0
M"0`)`$0```"H````!-#.`"M`"0#"4`/1*T#!4`D`"0!(````M`````30S@`K
M0`D`PE`#T2M`P5`)``D`3````,`````$T,X`*T`)`,)0`]$K0,%0"0`)`%``
M``#,````!-#.`"M`"0#"4`/1*T#!4`D`"0!4````V`````30S@`K0`D`PE`#
MT2M`P5`)``D`6````.0````$T,X`*T`)`,)0`]$K0,%0"0`)`%P```#P````
M!-#.`"M`"0#"4`/1*T#!4`D`"0!@````_`````30S@`K0`D`PE`#T2M`P5`)
M``D`9`````@!```$T,X`*T`)`,)0`]$K0,%0"0`)`&@````4`0``!-#.`"M`
M"0#"4`/1*T#!4`D`"0!L````(`$```30S@`K0`D`PE`#T2M`P5`)``D`<```
M`"P!```$T,X`*T`)`,)0`]$K0,%0"0`)`'0````X`0``!-#.`"M`"0#"4`/1
M*T#!4`D`"0!X````1`$```30S@`K0`D`PE`#T2M`P5`)``D`?````%`!```$
MT,X`*T`)`,)0`]$K0,%0"0`)`(````!<`0``!-#.`"M`"0#"4`/1*T#!4`D`
M"0"$````:`$```30S@`K0`D`PE`#T2M`P5`)``D`B````'0!```$T,X`*T`)
M`,)0`]$K0,%0"0`)`(P```"``0``!-#.`"M`"0#"4`/1*T#!4`D`"0"0````
MC`$```30S@`K0`D`PE`#T2M`P5`)``D`E````)@!```$T,X`*T`)`,)0`]$K
M0,%0"0`)`)@```"D`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"<````L`$```30
MS@`K0`D`PE`#T2M`P5`)``D`H````+P!```$T,X`*T`)`,)0`]$K0,%0"0`)
M`*0```#(`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"H````U`$```30S@`K0`D`
MPE`#T2M`P5`)``D`K````.`!```$T,X`*T`)`,)0`]$K0,%0"0`)`+````#L
M`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"T````^`$```30S@`K0`D`PE`#T2M`
MP5`)``D`N`````0"```$T,X`*T`)`,)0`]$K0,%0"0`)`+P````0`@``!-#.
M`"M`"0#"4`/1*T#!4`D`"0#`````'`(```30S@`K0`D`PE`#T2M`P5`)``D`
MQ````"@"```$T,X`*T`)`,)0`]$K0,%0"0`)`,@````T`@``!-#.`"M`"0#"
M4`/1*T#!4`D`"0#,````0`(```30S@`K0`D`PE`#T2M`P5`)``D`T````$P"
M```$T,X`*T`)`,)0`]$K0,%0"0`)`-0```!8`@``!-#.`"M`"0#"4`/1*T#!
M4`D`"0#8````9`(```30S@`K0`D`PE`#T2M`P5`)``D`W````'`"```$T,X`
M*T`)`,)0`]$K0,%0"0`)`.````!\`@``AB]RQY8OIB^V+\8OUB]OW.8O;]D,
M/")/PV&<,>A_$F'S:$,8$F(E&`#B4AAITO-E81@(=?-F\V0$=@,"#'1FT-AX
M9M/.!6;04V8#`\X$9=#.`1!A&"%VC1-J`M`2`<X``J`,,?P```"NDA)AC50L
M,1J$0VH$=`/+&H!;T18T`H\#>I.@"0!9T0,!"$2,4P-G5]`R878,$B=6T5?0
MS#&-51$7S@$2%U71S#$3%P'A%S4"C5-A@*`$Y0A!^'%S8@E!$'($<P%Q"0`V
M9A!!8B+[CP1R`W4(14K;?#5*T@#ALVT2)<P]2-6C9A(OTF0#`LPU""!!B471
MPV"^!/-M`P$0?4/2`VI#U--E`P+,-`@@.(E!T<-@`P&^!$#2`P()`,-AG#$2
M88]3$F`P,`#C`.!(CZ-@&'\F3_9N]FWV;/9K]FKV:0L`]F@VT0,!"0`#9"S0
M2"0SC48,,],#`PD``M`2`<X``Z`,,0D`_````!)A+)`,,:-@<:\:@"O3`P/2
M9+FO"0`JWLP^XF1()`6-TV4HT`,`"0"\KPD`)M,GU`,#S#0"+@@@M(T#9/&O
M"0`CTR30)-3.!0,#S#2-KPA%(M(#`@'D(M$#`0D`X`+`!:3C`0#P````(OW_
M_P@!``!R.@``#`$``/@```#___\_]/O__R0!``#X6/[_W/____Q8_O\H`0``
MI/W__S0D_O_8^O__3`(``'16_O]0^O__/OW__\3Z___4^?__OOW__R`!``!L
M(```N`$``!!6_O\8_/__!`$``#A8_O]F^___O/G__P#N]F7S9D8OYB\$U`#G
M!-$+00D``]$+00D`"0````````````````#&+PG'"-P)U`P\"=',-,PQ(D]`
M,06)!]#.`1@A`8D+00D`)D\+`/9LT.(!`.#____@____Z````,8O#<<,W`W4
M##P-U<PTS#5(-2%%(45380!!`.$>-2%%6"4&C2)/!]#.`1@A`8D+00D`)D\+
M`/9LB.(!`.#____@____$`$``(8O#L?&+PW<#=@B3PP\PV",`1@A#8L+T,X!
M&"$#B0K1"M`#`<X$"M`#``D``>'#8!0()D_V;`L`]F@)`#SB`0`8`0``Y```
M`!;W___,____5/___P'1(P$)``D`7O___T@D2XF&+R?'EB^F+\8O)=P,/"70
MS@$2:J@J08E`8`@@`HT]B"6/0V$`Z:)C.",:B:-G"0"8*3-H0V`,C9-F!&$8
M(06-A&(0,@*/'&$01O:++&(0,@.+DV`\`#V($HEQ4S@CYX\$=_9L,V#V:O9I
M"P#V:`%Q$VD48`@@`8T]B/F+TZ](.:@W]FPA1_9J(4<8`'(EGC/V:3-@"P#V
M:`L``.#AKP#C=.$!`!0!``"&+R#'EB]#:*8OMB_&+QW<'=HB3PP\'=/#8:PQ
MD'\28?-I,'D28B\9`.(#`_-E""`1C_-K%M*T42DA(9(@,0.)%-(@,0F/PV$3
MT0+E`P&#9`@@`:`I``#@PV&L,1)AGU(28R`S`.(`XP>+<'\F3_9L]FOV:O9I
M"P#V:`C1`P$)``!`"0#HX`$`\````-+Z__\`\````*```'CZ__\`]___AB]B
MQY8O2"2F+T-HMB_&+]8OYB]=W")/7=T,/+Q_PV'<,1)AP'_S:T1[$F(O&P#B
M!(W#84!A&"$5B\-AW#$28;]3$F`P,`#C`.`!B9J@"0!`?T1_)D_V;O9M]FSV
M:_9J]FD+`/9H2],#`PD`""#DC0-J2=.#80%Q%!_,,_-A%'$S'Q(?1=,#`Z-D
M""!9C0-B(VX3?N!@+H@$B^&$""#QB>!@+HA5C8-@`\AACX-D`.-&83PA_(O\
M=$1A&"$(C?111&$8(0.)1&$8(?_A&C3T4>-@`\@8-$:/XV$`YQ9C?"/\B_QQ
M%&,X(P:)%&,X(P.)%&,X(__C.C'H,1@`'C0HT0,!"0`GT@-I\U?_Y@'E`V3A
M'P,"@B\DTY-D\V4#`Q1U_X@&C9-D(=+Y42DA+9(@,2.)']$#`0D`'M(#`I-D
MH:\)`!W1`P&C9!S2`P*#9'6OPV'AA"Z(IX^#8.*$"""1C8-@HJ\#R!1C."/%
MB?RO%&-$81@AJXG\KT1A$=`#``D`VJ\)``_1`P$)``!`0-\!`/````"X^O__
ML%7^_T;Z__\L]___*OK__U3T__\`\```W/;__][T___`^?__(O7__X#^__]6
M]?__AB^(QY8OIB^V+T-KQB_6+X3<YB^$V0P\(D_#89PQ$F'P?U!@\V@28B,8
M`.(`X3V(4V`>,`/(T'@"C0-ACJ`48@#C%F(\(OR+_'$48B@B!HD48B@B`XD4
M8B@B_^(J,7/7&``3;0H]`VKS9;-D`P<(=0@@`H\!>HF@PV`#R'2/`V$`XQ9B
M/"+\B_QQ%&(H(@F-&``48B@B!8T8`!1B*"+_XBHQ&``*,18]9(N.4F#3"$*P
M8`@@`HT]B`*/LV&JH`#D`7$)`!-D%&`((`&-/8CYB[@TPV`^`U?1`GTR;MPT
M(1\L/@,!,B\"+@@@\5(CC?)C,F$C8!X!M&`]B!"-`"$((`V-$V("H`%R""`(
MB0%[(V&S8/!P#X0`(CV(]8\!<CWB("$!H`%Q`7JC8/!P#X0`(0@@^(\!<<-A
MG#$288]3$F8P-@#C`.9JBQ!_)D_V;O9M]FSV:_9J]FD+`/9H*"(!BWVO"0#Z
MKQ1B%&(H(OR+"C$6/9J)`:`#80%ZHV#P<`^$`"$((/B/`7'6K\-A*-,^`1)G
M<F$8(3^-<V$`[@1Q"0`68N-E*"+[CP%^`W4(12+1S#$28B@B((]S9`'B4V0B
M(1[1<1\#`3(O"""TC?%7<V4;U^-B"$(A'R-F`P<#9/)C`V'#8#X'$B?Q4N-G
M`7<(1^X8?#$`YUNO<B$2T0,!,B_R8P-APV`8(3X"E(T2(N-BZZ\(0EZOPV`(
MY<BO`.X*UP,'"0#@W`$`\````'S\__\4`0``@O7__QP!``"@]/__6O+__U#S
M___T\O__AB\RQY8O0VFF+U-JMB_&+]8OYB]7D2W<(D\MW@P\&#]2G2S3PV'L
M,2O4$F'\/4R6S#028B\=`.(#`_-E%4#S:P:/`VC_<+P!&"$CCP@@'XLBTP+0
M$@'.``*@##'\````HV829`,#DV7#8>PQ$F'?4A)C(#,`X@#C(HLDEWP_)D_V
M;O9M]FSV:_9J]FD+`/9H`V@)`!+1+^6#9@,!\V0((-:-@V</T@+0$@'.``*@
M##'\````$F3S9@,"DV75K\-A"=$#`0D`!!#$#_\/[-L!`/`````X\___N%7^
M_]3R___J]/__K/7__P;R__^&+Q/'QB\2W!+1##P2UP+0$@C.``*@##C\````
M(D\/T/A_#]7,-\X&@F0#`<PU`.$,UQ$?#-',-PS6#=5R+\PV@F0#`<PU"'\F
M3_9L"P#V:'S;`0`:]/__>);^__0```#(5?[_]%C^_\;T__]`.O[_Y%7^_\8O
M#,<+W")/##P+UP+0$@'.``.@##$)`/P````29`?1S#<'T`?5S@8#`<PU)D\+
M`/9L"0`DVP$`>);^_ZCS___T````R%7^_X8O+,>6+Z8OMB_&+TV1*=PB3RG:
M##P8/RC31YG#8:PQ\V@28?PY"'A!FQ)B+QD`X@,#_#LBT8-D(M<!Y<PQ-Y81
M'\PW(-$#`0(O(-.#9#"6`P.S91%`(X\#:!W1`V0#`0%T""`)C0-A&M*#9K-E
M`P(#9`#B`V&#8"0!PV*L,B)BGU,B9S`W`.,`YPN/$V`,EWP_)D_V;/9K]FKV
M:0L`]FCKKP#A#-`#``D`%"#4'PP0`1``$%S:`0#P````"/+__PA6_O_\5?[_
M.O7__WCQ__\2\O__)O#__WKP__\%T0;'QB\%W")/##P#`0D`)D\+`/9L"0`4
M____&-H!`(8O5L>6+T-HIB]3:K8OQB_6+^8O(D^;D5#<&#^9D5#3##S\,4_2
M%!_#89.7/#$28?-N3=3\-Q1^$F`!%P#@S#0#`N-E2=,OY0-I`P.#9`@@'HE'
MUX-E1]0#!\PT@V!`T\-A=Y<\,1)A_#=Q4A)C(#,`X@#C`8E#H0D`:9=\/R9/
M]F[V;?9L]FOV:O9I"P#V:#G1.ML#`:-D.=(#9+-E`P+,-0@@U8T#8S;2,&%3
MG<PR(Q\8(5":`X_\/<2@F"D)`)@I"0`>C9-@.R`#R)-E`HTS9^.@=&%V8E9@
M`.8C80DB;"("CQ`PU:#\=?6-=F((8!AA"6`980A@&&$0,`./,V"1H`D`,V`#
MR`*-,V&QH!1B`.<68GPB_(O\<11B*"()C1@`%&(H(@6-&``48B@B_^(J,1@`
M$V+^<3-F.C(!=A(S,V$L,1-G`.4CCV@W.J"#8(001!!\$(``_P\)`+C8`0#P
M````N/?__Q!6_O^:\?__M/K__QQ6_O_H[O__+%;^_^KR__\P5O[_$$<"CU`A
MDJ`S8/]Q$&`OB/:-,V`#R'&/,V(`YR9A?"'\B_QR)&$8(0:))&$8(0.))&$8
M(?_A&C)H,H-@`\A)CX-A`.869VPG_(O\<11G>"<)C1@`%&=X)P6-&``49W@G
M_^=Z,1@`BC$8`"XQIC$>C0'E0]'S5]-DS#&`EA$?0=$R+P,!@A]`TN-E`P+3
M9`@@!8L^TN11*2$]TB`Q7(D]T@#DLV4#`LPU""`"CP-C#*\)`#!A&"$!B4"O
MF"F8*0*)D&`NB"Z)--.#8`/(`>+,,[>-@V$49PD`>"?$C1@`%&=X)\"-&`#W
MKQ1G*"("B11B*"(!BUJO&`#WKQ1B)&$8(9J))&$8(9>)^:\D8?QW"0!T80D`
M&"$#C51@$##XC1QA)Z\,8)&$"""YB<RO"0`#R`B/,V(`YR9A?"$!BW*O_'+Z
MKR9A)&$8(0*))&$8(0&+<Z]H,O>O)&$0TP'E`P/39`@@G(L.U]-E#M0#!\PT
M#M$#`=-DKZX)``S7`P<)```0.%;^_WKR__^F[/__`/````"```!<\?__#%;^
M_XCP__\:^/__'%;^_X3L__\B[?__AB\*QPK1+^7&+PC<(D\,/`,!0V@((`&)
M`V@!>`71`P&#9"9/]FP+`/9H"0"PU@$`L/#__R;L__^&+T3'EB]()*8OMB_&
M+WZ10-PB3T#:##P8/WF9PV&L,1)A_#D28B\9`.)?B4!A&"%<B4-@`\A-CT-F
M`.)F82PA_(O\=F1A&"$&B61A&"$#B61A&"'_X1HV6Y$8`&-H2#9*.!8V)(T`
MX"S10V7S9`,!\VN#8?]QO#$2.PV-&`"S88PQ$V(`XP*@NC(%C3`A_W$08"^(
M^8T00B'2+^4#`O-D""`KC;8P)XT`X1[1`P'S9,-AK#$289]2$F,@,P#B`.,B
MBR27?#\F3_9L]FOV:O9I"P#V:&1A&"'\CV-H&9%(-DHX%C;`CP#@XZ_#80[3
M#]0#`\PTW:_#8=>O$"`,TPO4`P/,--6OPV$*T`,`"0`$$,0/`!"0U0$`\```
M`+KK___L[___8.O__QSK__\,5O[_#.O__ZKK__^&+Z7'EB^F+[8OQB_6+Z+<
MYB^BW0P\(D^AVL-AH=O<,1)A^'_S:<PZR'D28B\9`.+,.PD`G-/S90,#HV0(
M(!")LF&>4A)A"$(L,1%2*"+QC2(A!'$14B(A*"+[CP1QZ:\)`)+:C]O,.LP[
M"0"0T?-E`P&C9`@@$(FR89Y2$F$(0BPQ$5(H(O&-(B$$<1%2(B$H(ON/!''I
MKPD`AMJ!V\PZS#L)`(32\V4#`J-D""`0B;)AGE(280A"+#$14B@B\8TB(01Q
M$5(B(2@B^X\$<>FO"0!ZVG/;S#K,.PD`>-/S90,#HV0((!")LF&>4A)A"$(L
M,1%2*"+QC2(A!'$14B(A*"+[CP1QZ:\)`&[;9=JS;LP^S#ILT?-E`P'C9`@@
M$(FB89Y2$F$(0BPQ$5(H(O&-(B$$<1%2(B$H(ON/!''IKPD`8MI7WLPZS#X)
M`&#2\V4#`J-D""`0B>)AGE(280A"+#$14B@B\8TB(01Q$5(B(2@B^X\$<>FO
M"0!6WDG:S#[,.@D`5-/S90,#XV0((!")HF&>4A)A"$(L,1%2*"+QC2(A!'$1
M4B(A*"+[CP1QZ:\)`$K>.]K,/LPZ"0!(T?-E`P'C9`@@$(FB89Y2$F$(0BPQ
M$5(H(O&-(B$$<1%2(B$H(ON/!''IKPD`/MXMVLP^S#H)`#S2\V4#`N-D""`0
MB:)AGE(280A"+#$14B@B\8TB(01Q$5(B(2@B^X\$<>FO"0`RVA_>S#K,/@D`
M,-/S90,#HV0((!")XF&>4A)A"$(L,1%2*"+QC2(A!'$14B(A*"+[CP1QZ:\)
M`";:$=[,.LP^"0`DT?-E`P&C9`@@18WS9>)AGE(280A"+#$14B@B\(TB(01Q
M"0`14B(A*"+[CP1QYZ\)``D`U-(!`/`````\5O[_%`$``!CS__](5O[_X/+_
M_U!6_O^H\O__7%;^_W#R__]D5O[_./+__W16_O\`\O__$%;^_\CQ__^`5O[_
MD/'__XQ6_O]8\?__F%;^_R#Q__\<5O[_Z/#__R72)M0#`LPT""`$C0-E)-,D
MU`,#S#0DT?-E)-0#`<PT""`$C0-E(M(BU`,"S#0BT_-E(M0#`\PT""`<C0-E
M(-$@U`,!S#3#8=PQ$F&?4A)C(#,`X@#C'(^S9!O5&]+,-,PU"'\F3_9N]FWV
M;/9K]FKV:2,"]F@6TO-E%M0#`LPT""#@C0-E%-,4U`,#S#3;K\-A$]$#`0D`
M4/#__Z16_O]6\___C%;^_SCP__^X5O[_/O/__\Q6_O\@\/__V%;^_R;S__\0
M5O[__%;^__;R___8[___Z%;^_][R__^`5O[_[.?__X8O&<>6+\8O%]P8V2)/
M##P7T\-AG#'X?Q)A%M3S:/-E$F(A&`#B`P/,-`@@%XW(>`!@,(@I`0@@*0(3
M8"L@`<K#89PQ$F&/4A)C(#,`X@#C!XL(?R9/]FSV:0L`]FCOKP#@!=$#`0D`
M)-$!`/````!*[___@%;^_SCG__^&+_CBEB\IQZ8OMB_&+R)/D'\FW/-A&'$I
M(1-B&')I$01R>A$,/%@1$V.J\B!SN_)#9A-B$'($<AW7BO*;\A-B"'($<AO0
M:O($<7ORPV)\,DKQ(F?S8EOQ,'(7$BQQ-1)R95\2`.46$@'ES@$X$AJ3)5K\
M,R9;$F3S83D26''S8DQR(FBB(;$1"]<A6301@A&3$30?HB^Q'X(?`P>3'P?1
M`I0#`0D`B`#_``D`9-`!`/````#L````4N7__R+H__^&+T_'EB\`Y:8OMB__
MZ\8OUB]#;>8O(D]*T4G<2M(8/TK6##S\,DK7(B_#84G2;#$28?PW`.828`07
M`.`#`@+G"``3:@X[_^&S9AXZHV$`01HQ$V<(`"E'?C9M8@@`>C(`XP#A.C$(
M`"H[&CH12E>/_^`YV?-H!'C,.0D`-](`Y[-EHV8#`M-D`V(38/^(28TC8#/2
M@V4SU@,"TV3_B$>-!^$6,#&/^'"#;@P^@CX#B2N@"0""/BB+*]<(YI-E`P?C
M9`@@]H__?@%^XV&(,1<P$V`Z,P@`,V&^,*XQ&]/#8AO6/#(B8OPV9%<B8W`S
M`.<`XR&+$]=\/R9/]F[V;?9L]FOV:O9I"P#V:!C0_^$..QXZHV#_B+&+%-$0
M.ZZ/_^#<K__A_XBTBQ'1$M0#`<PT$=,2U`,#S#01U@,&"0`)`!#/`0`0``$`
MT/\``/````#\_P``!.?__]#___^\YO__L.3__P@``0!JY?__``#__Q#^__\`
M5_[_"/[__Q!7_O\FY?__"-$)Q\8O"-PB3PP\`P$)``;1`P$#9`@@`(D"8"9/
M"P#V;`D`[.3__Z3.`0#.X___AB]0QY8O0VBF+[8OQB_6+TS<YB],VPP\(D_#
M8;PQ$F'L?_-J2=D28B0:`.)(T?-EDV0,=0,!S#0((-1Z!(T#;0!A&"$7CX-@
MPV&\,1)AKU(28R`S`.(`XW&/DV0]T<PT@V44?R9/]F[V;?9L]FOV:O9I(P'V
M:`/(6(^#9`#B1F$L(?R+_'1$81@A"8T8`$1A&"$%C1@`1&$8(?_A&C08`--@
MBC0#R#F/TV$`XQ9B/"+\B_QQ%&(H(@:)%&(H(@.)%&(H(O_B*C'8,1@`'C0B
MT0,!"0`AT?_F(=(!Y2'7S#$1'P-NTA_,-X(O`P(#9,-AO#$28:]3$F`P,`#C
M`.`;CY-D&=+,-.-E%'\F3_9N]FWV;/9K]FKV:2,"]F@48B@BTHD48B@BSXGY
MKQ1B1&$8(;:-&`#[KT1A#-$#`0D`#-`#``D`6,T!`/`````<5_[_3.S__R+O
M__\LY?__+%;^_R+H__\P5O[_?.[__W+C__]LX___AB])QY8OIB^V+\8OUB_F
M+T7<(D]%UPP\?Y*$?\-A?#&$?Q)A>I#\,B<?\VL28B8/`.)TFC[1)'O\.C[3
MS#%OF!(JS#,\T?PX(AJS9<PQ(A@1&F:12!_\,3C4,1$XT\PT)1',,S?2,A$W
MT\PS,Q$WT\PS-!$VT<PQ$B@VT<PQ`P(1&`@@!(D`81@A`8E1H0-D,=$#`0D`
M,=(#`@-D""`#B0)NZ"X"C^-@&*&&9`/(`HWC9"JA1&$`XD9A+"'\B_QT1&$8
M(0:)1&$8(0.)1&$8(?_A&C0BUQ@`ZC3C:!@``7@#!TXTX&$8(1*-`VF#;1W8
MDV[,.!QA"0#C9!(O_^8:T0'E@V<#`0)^U&$8(?2/'&$(F!;4_#@NH,PTN`#T
M`)``G`"H`*P`"0``S`$`\````#17_O_05O[_#%;^_Q!6_O\\5_[_CNK__Q16
M_O]$5_[_2%?^_U!7_O_"XO__I.'__ZCC__]<5_[_E.;__\Q6_O^&9$@D%(EU
MT@,"LV4((/>-`VX`81@A\XEQTP,#`V0((.Z)<-<#!^-D""`5CP-M"0"F;=@M
M$8T`X]!A&"$!B[6@`.UIT0,!TV0((/&)9](#`M-D""#LC0-M`./3;N9A/"'\
MB_Q^Y&$8(0F-&`#D81@A!8T8`.1A&"'_X1H^&```Y]H^DV$68GPB_(O\<11C
M.",)C1@`%&,X(P6-&``48S@C_^,Z,1@`E).:,5'7'#Y1VCP^`P?C9%#1_^90
MUP'ES#$#:!(?HV',,0-D$1_,-TS1DQ\#`=(O2])\E0,"@V3_B`B+2=,#`PD`
M`F(C8!&(`8E?H<-@1=>S90,'@V0((`B/`VE#TK11*2%EDB`Q`8N5H+910-`!
MY8(OS@'X4Q)D/M$^UC)G`P',-@#N/=+#85.3+#$28?PS/E<28'`P`.<`X`*-
MXV`PH@D`?']\?R9/]F[V;?9L]FOV:O9I"P#V:#'3`P,)``@@(X\#;H9D2"0+
MB2W2`P*S90@@]XT#9`!A&"'MBX9D2"3SBRC1*=@#`0WD&`!3X<XX\:X#:1@A
M`HE$81@A`8O>K@D`]Z]$856O`.,`X@-D1F$L(0&+R:[\=/JO1F$<TP,#!A\;
MUP,']E2LKP-N!`3``0!`O``)`)3I__\NZO___.#__P3J___2X/__9N+__SA6
M_O]P5_[_9%?^_U;E__]RX___%./__U#D__\`\```[````+#D__^T5_[_\```
M`,#?__\JZ/__C.'__RQ7_O]4^___5M___V72`P(5'_51`#$%B\&2M%$I(<%R
M(#$!B5VO"0!?T@,"XV1?T[-E7]0#;@,#S#0((`>-`V5<T_A2`P,B9`@@`H\#
M9O&@^%%C8`/(`HUC8=>@%&(`XQ9B/"+\B_QQ%&(H(@F-&``48B@B!8T8`!1B
M*"+_XBHQ&``#XFHQ)C$FCQ-@_'!*UVPP`\@"C<PWQ*!T8G9D!F,`Y4-B.21<
M)`*/(#.WH/QP]8UV9#AC*&(Y8REB.&,H8B`S"8\38`2(!(EL,?MQ$&`OB`&+
M!J'X43C1LV4XW68?TV0#`<PT""`%C?96`&`((`&-,(@!BY^@`.4RTM-D,M7,
M-#+;,MT#`LPU,M/,.P,#S#VC8<PQ$1__YB_1`>4OU^-DLQ\"'\PW`P&"+Q:@
M"0`KT0,!"0`"8!&(%8LIT@,"`7DITZ-AS#&T'Y,?_^8"'P'E$1_39X(O`P/C
M9"/7'Y4#!^-D_XCCB2'2`P*#9"'3XV4AU`,#S#0@UP,'XV2\K@D`']$?TP'E
M(1\>`?A2'M:"+R)GS#8#`Q)DKJX`[O\!P`$)`*;?__^^X/__-N?__PA8_O\L
M[___$%C^_XKF__^`5O[_>NG___Q6_O_T6/[_3%C^_Z+?___0XO__/%C^_Y;@
M__]RW___H.+__[S@__]JW?__#.G__Q!6_O]N^?__[`````[B__]X5_[_*"("
MB11B*"(!BS2O&`#WKQ1B_'=T8@D`*"(#C01C(#/XC2QB1J\\8PVO$F95T@,"
M8V0((">-`VM3TP,#`V0102&/"!]1T_;E"`#_Y@XULV0>-A8?`P,`YX^1!N9,
MU[-D_#$5'P,'$V4&B/51`HWV4G^@"0`29T?3,#<$BQ*%?9,-83`Q`8DRKPD`
M^%/.Y0@`_^8^-;-D+C8_TG"9`P(`YS[3_#DHYI-E`P.S9"B(8(\`X&61.M?,
M.OPQXV08@,PW.-'_YI(?`>7,,:$?$Q\VT0,!@B]"KPD`$5,X(S.-,V`#R#*/
M,V$`YQ9B?"+\B_QQ%&(H(@F-&``48B@B!8T8`!1B*"+_XBHQ&``#XCHQ)C$9
MC_QQ)=<S8!PP`\@=C\PW=F0&8@#E0V$I)%PD$XT0,O>-=F0H8AAA*6(982AB
M&&$0,@"+,V;!K@D`%&(H(MR-&`#[KQ1B_'#\=W1A&"$#C01B$#+YC1QAZJ\L
M8A#1`P$)`!#0$-0#`,PTP`!(1<@`Z``)`%;?___N]O__&-[__Q#<__\`0T%#
MT-W__\S;__\L6/[_]%C^_QSA__\86/[_'MS___+T__\@6/[_AB]SQY8OIB^V
M+\8O<-QQVM8O##PB3\-AK#$28?A_\VEMTQ)B(1D`XFS4`M`2`<X``J`,,?P`
M```2:\PT\V6S86!Q&(3(>0,#&8`((`6-`V$`8#&(`8N:H!&$8=`#``D``M`2
M`<X``Z`,,0D`_````!)K7-&S9%S5`^<!Y@,!S#4((!:-`VM9T@-1`M`2#<X`
M`J`,/?P```!5UA)ETF0#`LPVLU%3TQ)E4E$X(0&)?:`)`%'2`M`2#<X``Z`,
M/0D`_````$W5`^?29`'F`P+,-0@@#8T#:TK3\V5*U`,#S#0((%J-`V9(T+-1
MTF0#`!)E`M`2"\X``Z`,.PD`_````$+2`>:R;4+5TV0#`LPU0=,#94'6TV0#
M`\PVLF$`X#_4\V5@<3[;&8#,-#[1`P',.P(K""`?C0-H.]%'E0,!@V0!X0-B
M`7(6,@./`V<1B#*/PV##8:PQ$F&?4A)C(#,`X@#C,(L(?R9/]FWV;/9K]FKV
M:0L`]F@MTBW0`P+.!`(K""#9CP-H*],KU`,#S#0((`&+;J\)`&"O"0"S4230
M$F0FT<X"`P$B9:*O"0`DT0,!TF1^KPD`'M$BU(-F'@$292'1`P',-"'0`P`)
M`,`!"0#PPP$`\````%[C__]D5O[_].___\#<__]@6/[_HMO__V18_O\``$``
M<-S__VQ8_O_(XO__'%;^_U3;___:W/__<%C^_RK;__^(6/[_$%;^_R`!``!X
MXO__&-W__QKW__\D`0``DMS__Y!8_O]@Y___%MW__[18_O]:W/__"-K__X8O
M0L>6+T-HIB^V+\8O/]P_VB)/##P_T\-AK#'X?Q)A/=3S:?-E$F(A&0#B`P/,
M-`@@#HW(>0!@,(@I`0@@*0(K(15!!8V(*`2-PV&`81@A$(O#8:PQ$F&?4A)C
M(#,`X@#C3(L(?R9/]FSV:_9J]FD+`/9H*=$#`8-D*=(OY0-K`P(#9`@@`8D#
M:P%[)=,#`[-D)=(#8P!AS#(@8`@@&(T`,1:/#&`QA`-A(80((!"-`#$.CPQ@
M,H0#82*$""`(C0`Q!H\,8#.$`V$CA`@@`(D,8!QA`#&]C\-AK#$289]2$F,@
M,P#B`.,,CX-D#]$(?R9/]FSV:_9J]FDC`?9H#-`#``D`"]`#``D`"0!DP@$`
M\````"CA__^`5O[_4NS__]3<__]*V/__<%?^_Z;A__^`V/__>MC__X8O,L>6
M+Z8OMB_&+]8OYB\B3U61+=P8/U.1+=,,/$#@+-C\,/-F_#%`$!00PV%)E#PQ
M$F%4=@!7_#0GT!)E5A0`Y3AW;Q\`Y&-C".5R81!%<5((=QAA01,982-F&&%#
M$Q(C*48C81E!&4:)(6LA(V8H1AA&&$)K(0DB*R$2$^6/$',@D$#J_#H>EP-B
M.'#\,J5;+%E4YBI3_#<K4?PV+5X#8J-@_#((5!!V(F4A70=23A]S9'$00."F
M6IP?$*`M']@"F`*\`I0`U``)`&S!`0#P`````/\`````_P"='XX?8FEC8BQ7
M85@(=BU2FB<Z)_Q3BB*Z)_U;&B)Z'ZHB^E$K'U-J^E+39P#MK!\`0M$4`$$C
M9?M1_EHD01LEXV%2)!!`"'3:CW-N0.#_WOX)!>C^"N7G_@T(`/X`DFD#4*%:
M!A]`X/X!_@,44?X"-E,E4A4?HV&9'XU!,Q^38WU#DV=`Z?X$C4?^!1LC_@;\
M.20?<V([(I53Y>E85=)=[C-'5`@`:59>,]<?"`!"'SXR41\(`/55'N1B+^7F
MJ!\`[?-:]U"J):-G"24#85HG`V-^,O97"4'Y54U'"`!-0_-4>R'U5SLA^5,3
M:!HG0.#U45DG(V7\,'HA!U=M1>XW"``>ZDXW(V0(``E#?C$%YP@`?43Y5T-F
M6R9N,?A6K4<(`*U&]5IK(Q-K>R.#9T#F,V4Z)RDG_#9S8VE7BB/EYNXW"``%
MX*XW$VH(`&U*?C,%YP@`?4LC9[-FJR8>Z@E'K4)[(E-G;C,C:BHG"`!`YADG
M_#9S8FM76B(>YNXW>A\(`/I7CC<S:`@`G4A^,A-G;4$S:0E'"`![(:-G&B<Y
M)PU)DV"+(!-H<V%`Y_PW#C)]5@@`JB'N-B-D;!_EX'Y6,V<)1]XV:A\(`/Q6
M#40C8%XV"``%Y6XQ'N8(`&U#>R.#9SHG*2==0`-E2R4S9'-C0.?\-UXQ?U4(
M`(HC[C43:UH?"`#Z5^7FKC<3:@@`;4I^,P7G"`!]2R-GLV:K)A[J"4>M0GLB
M0V=N,R-E*B<(`'SF,VD9)S-J_#9S8F)72B+N-WH?"`#Z5XXW"`#EZ'XR!><(
M`(U)?4H39Z-HFRB.,A[H"``)1R-@C4%[(5-G&B<3:#DG<V%\Y_PW=%9:(>7J
M[C9L'ZU`=58S9PE'(VK>-FH?"`#\5DXV"``%Y&XQ'N8(`&U#>R-4YTU*_#>C
M9$!W"R0`ZDC@I@].,7!6"``S8(-C[C83:@HC"`!>-A-K*2,(`#-DBB1N-"-C
MY>4(``7F74IM2[-FJR8>Z@E#K4).-CLB<E,(`"-E[C,#8@@`6B*.,V-I&2((
M`"-D"B0^-&-JY>,38@7H"``]28U*HV.;(Q[I"4*=04#J*R'\.@#B3C,C&G12
M"``39%-A[C(S:4HA"``.,C-J:2$(`!-H6B@N.&-AY>`(``7B#4DM2J-BFR*.
M,A[H"``)02-IC48C:ALF0V%C8&HA=E8Y(1-H2BCN-C-A"``)05XV"`#EY6XX
M!>8(`%U);4JC9ILFCC8>Z`@`C4-C:1LC`V$S93HA>%,I(1-H"BCN,V-J"``C
M84XS"``%Y#XXY>,(`#U)34JC8YLCCC,>Z`@`"4$S:8U",VH;(E-A(V0J(7I2
M:2$3:%HH[C)C80@`"4$.,@@`!>`N..7B"``M20U*HV*;(HXR'N@(`(U&(V@;
M)D-A8V!J(7Q6.2$3:DHJ[C8S80@`"4%>-@@`!>6N-N7J"`"M2"-J74JC9XLG
M;C<>Y@.@"``)`)EY@EIM0QLC`V$Z(3-F*2$C8Q-J5.'\,7AQ$FL**@7HHV'N
M.W-J"``)0TX["`#EY+XQ<VM-2@@`C4NS:*LH'NJM0CLBCC$C:&-BBB)Y(@@`
M(V/^DFHC$VG\,A-K)E3EY>XT3!\G5'-B"4+>-$H?"`#\5`XT"`#EX$XS!>0(
M``U)34NS8)L@'NF=1RLG<V2#9THG&2=S8MR7#C/\-P@`>%F*(C-K[CF<'WE9
M$V<)1]XYFA\(`/Q9!>UN.0@`!>:>,C-I;4L(`%U)LV6;)1[IG4%[(1-F0V%J
M(3DA$VFYD5XR_#$(`!I72BDC:B-K[C=Z'P@`^E$S9PE'CC$(`.7H'CD%X0@`
MC4H=2Q[HLV&-0ZLA,VB>,9V9>RAC8XHC"``I(Q-@_#DS:IQ3:BJC:>7J[C,(
M`*U`3C,3:MU*"`"C9`LD'N`^.2-C#4((``E#0]`[(H-C*B,S9WR33CG\,P@`
M/EH:)^7EDVL..A-C"`#=2VXZ"``>YJXWDVI=2K-EJR5IF@E#"`!M09-F_#I>
M-SLAH%,(`.7M#C,C:@@`&BJ.,W-K!>6C:%U+<VJ:*`@`W4J.,[-HJRA.F@@`
M"4G\.HXSHE4>Z`@`#C4C:HU&"`!K*5-BKC(3:IHJ,VL>Y:-H,VK=2@7M<V9Z
M*`@`W4M=1XXRLVBK*'-J+Y<(`(XRDVC\-P@`<F4)1FLJ(VL.-0@`JB@>-8-F
MY><C:#HF"`!]2!R7W4LS86XULV:+)@@`'NBC:_PW"4&-0VXU&R-P40@`.BL.
M,5-M"`#EYIXQLVD(`"HI!Z">,;P`_``,`10!"0"AZ]EN4VL%Z0@`;4N=3=-F
M'NV[)C-K'C8C8=U""``)06-M&R)R42HK#C$(`.7IKC&S:@@`6BJN,6-K!>H(
M`)U+K4W3:1[MNRDC:QXY4V'=10@`"4&3;1LE=%%:*PXQLVH(`&HJ/C&3:P@`
MY>BN,6-C!>H(`(U+K4W3:+LH'CAV41[M"``.,5-K"4,(`-U&@VT[)BXQDV)J
M*P@`LVJ:*JXQ@VOEXP@`!>H]2ZU-TV.[(QXS>%$>[0@`#C%C:PE""`#=23-M
M*RE>,8-EFBL(`+-JBBJN,3-KY>((``7J+4NM3=-BNR(>,GI1'NT(``XQDVL)
M10@`W4@C;5LH;C$S9HHK"`"S:CHJKC$C:^7E"``%ZEU+?%6M32-GTVJ[*JXQ
M@VH>[0@`#C43:PE&"`#=0VLCGC4Z*@@`Y>:C:2HI$VK=0IXU;4HC9@7I_I*=
M2P@`"4>S:?PRJRF#:IXU>R8B9P@`Y>T.-U-K"`!S:*XX,VIJ*@@`!>>C:1HI
M4VJ>.!-BW4H(`'U+X9>S::LIGCAC:Q[I"`#\-PE"G4$3:2LI<%*:*[-J6BH.
M,H-K"`#=2SXR@VT%XP@`KC)383U-"`#3:KLJKC)R4Q[J"``.,Y-K"4$(`*U%
M&R6#86XS6BL(`.7MLVH%YB-KBBJN,]U+(VUM30@`TVJ[*JXS4VL>Z@@`"4$C
M9JU(&RAT48HK#C&S:@@`*BJ>,3-KY>T(``7IKC'=2S-MG4T(`--JNRJN,8-K
M'NH(`*U"(VEV4@E&#C)K*0@`7C(S9IHK"`#E[;-J!>43:SHJKC+=2Q-M74T(
M`--JNRJN,I-K'NH(`*U#,V5X4PE&#C-K)0@`CC,39EHK"`#E[;-J!>@C:QHJ
MKC/=2R-MC4T(`--JNRJN,U-K'NH(``E&(VBM06LA>E8:*PXVLVH(`"HJGC8S
M:^7M"``%Z:XVW4LS;9U-"`#3:KLJKC8>Z@@`"4AC:ZU"$VJ+(GQ8*BJ#9PXW
M"`#E[5XWHVD%Z`@`.BEC:IXW,V7=2@@`C4NS::LIGC<>Z0@`"46=0W-I6R,>
ME3-HY>W\-5)C!>5=20XS(V`(`(H@'C,#9`@`:B1.,W-@Y>1C84U`DV0>Z0@`
M"R0)09U&3C,$E`2@&R9,`50!C`&4`8-A:R$(`/PT8V5Y(8-F`.`3:@\?629`
M4&LJ[=$>YC-I'C`(`"-AY>(.,2U)<V)M1P@`"4)39BLG!>"N,3-J>R8(``U*
M.2:C8)L@X=H.,6-B0E8(`%-I>2FN-A-J"`";(HXV$VD(`-U);C)S8`7F"`!M
M2C-GHVB;*(XRU=T>Z`@`C4,#:`E'`VD[)Q-F>R@9*(-C1%AY*=XX(VT(`)LC
M7C@C:0@`!>6.,^7H"`"-25U-<V73:)LHCC,>Z`@`C48S:PE!:R$3:'-ABR$I
M(8DE$VU&45LMOM7EYFU+(V9>,0@`'N4.,0E&"`!=0FLB@V8%X"-EWC&#8C-M
M6R(-30@`.2+38%DF(VV[(+'2#C%K+4A6"``%ZBXV$VMJ'P@`^E(%Z7XR"`#E
MY]XR$VVM30@`TVH>[7U+,V?=0PE'>R-39S-F4V-K([LJ&2-I)S-MKC)*4WLM
MG]<(`"-K?C,(`!-GCC,(``E'WC,C;9U-"`#3:1[MW4%C;7LA(V?EZ(U+$VAC
M88LANRDI(8DMGC,3:4Q1VRF/W0@`Y>0S8-XQC=T(`$U`7C$(``7EGC$S:5U)
M"`"39![I"4>=0GLB@V<+)"-@@V(+(CDB"2=.,2-D>R3^EP@`Y>7\-Q-J<F(S
M9PE'WC((`.7I;C(%Y@@`;4H#9DXR$V1=1*-E'NH(`*U#2R7GE'LC7C(S90-C
M6R/\-`@`&2,C;5DF,V=NTVLG0%8C:P7J/C9J'P@`^E,>YHXS"`#EZ#XW!>,(
M`#U-$V-M00E#.R%38Q-FC4M386LA*2'3:&DC$VV[*$)1CC<[+5W3"`!S:SXQ
M"`"=2PXQ(V,%X`@`WC%S;0U-"`#3:;LIGC$>Z0@`"4,3:YU".R)C8R-@8V(+
M(GDB"2,C;4[2.RU$4RXS<V((``E"7C,(`.7EWC,3;:U-"`#3:A[MW4<K)P-B
M74L#97LBNRIS:QDB>26N,R-J1E);*C_5"``%YS-H7C((`&XR"`#EYJXR,VIM
M2`@`?4H39Z-FBR8>Z`E'C4%[(1-HLV&+(6XRLV8Y(0@`B28394A1:R4OUN7G
M(VEN,0@`'N8.,2-@"`!]0%XQ,V<%Y0@`"4=M0WLC@V==29-E"R4S8(-C"R,I
M(PDG7C$S92'3>R5*5P@`!>83;3XW>A\(`/I3;4TC9PE'OC,3:P@`7C/EY0@`
M74O391[MW4(#;7LB$V<C9@-B:R*[)1DB:2TC:UXS3%+;*P_="`#EY-XR,VH(
M`$U*CC(+W07H"`"^,C-KC4L(`+-HJR@>Z@E'K4%[(6-GCC(3:&-ABR$Y(0@`
M!*"))\P!U`'<O!N/$VI[*OZ7!>0C:?PW<F$S9PE'WC$(`.7M#C$(`.7@KC$C
M:@U)"`!-2H-DHV";(![IG4,.,>>0>R.#9SLG,VG\,`@`*2<Y)'-C<-=+(P!4
M!>5^-"-G"``)1VXT"``>YDXS$V1M0@@`W403;5U->R+394LEDV=>,R-EDV);
M(ADB"`!9)R-F8=)[)@)7,VTS:RXW$V((``E"CC<%Z`@`C4U^-M-HY><(`![M
M?4M8U]U!NR@K(5-BCC83:%-ABR$Y(0@`B2(3;2LM!%(S80E!?C)C:@@`(V>>
M-V-K'N((`-XWY>D(``7M+4.=2MU+2-T;([-IJRDS:H-CJR-I(V-AGC<S8@93
M"`"#::DIWC-S9`@`FR)>,W-I"``%Y2XSY>((`"U$.])=29-E2R5>,PA5'ND(
M`"XU,VT)00@`G48S;ALFHV&.-7-D:B$(`!-I>BE>.?E1Y>4(``7H74V-3N-E
MVR6>-1[I"`"=1PI9"413:RXY4VU+)P@`KCEC9'HD"`!#:#HHGC@S9.7J"``%
MZ:U+G4W3:KLJKC@>Z@@`"42#:ZU#8VI+(PQ4Y>U#8"XP"``#9JXV<VHZ*@@`
M!>"C:5HI@VJ>-E-DW4H(``U+LVFK*9XV<VH>Z0@`"41C:YU%2R44E/PT0F"#
M9`E$+C`(``-G'N"N-S-J6BH(`*-IBBD-2$LH!)0(H&-J#`(4`DP"5`+<O!N/
MUL%BRMU*!>V>-]U+"`#\-+-IJRDS:YXW0%D(`'-M+CD(`)-COC-3:XHK"`"S
M:FHJKC-S:P7J"`#EZ:U-G4O3:1[JNRF#:SXY8V.M1@@`"4,[)D)3:BLN,[-J
M"`!Z*EXSDVOE[0@`!>6N,]U+DVU=30@`'NK39;LE8VL^-7-CK4<(``E#.R=$
M4WHK+C.S:@@`FBJ.,U-KY>T(``7@DVBN,]U+4VT-30@`TV"[(#XP<VL>XP@`
M/4E&4PE(`VTN,XLI"`!N,U-HFBL(`+-J6BJN,P-KY>8(``7J;4NM3=-F'NV[
M)I-K/C938]U#"``S:DA3"4AC;2XSBRH(`'XS`V>J*P@`LV@**(XS8VOEY0@`
M!>A=2XU-8VC39;LE/C5*4Q[M"``N,Z-K"4<(`-U`4VU[()XS"BL(`+-I:BF>
M,U-K!>D(`)U-Y>=]2]-G'NV[)PE(W48^-_Z3BR9,6`@`Y>0N.'-K"`#\,ZXX
M`VIJ*@@`HVE:*9XX<VH%Z0@`34I39)U+LVFK*9XX,FD(``E$+CEC:MU%"`!+
M)7-D#CF#:UHJ"``>XZ-@"42#:GH@/4=+)]*4#CGE[0@`!>#=2@U+_#2S8*L@
M0%,..5-K"`!Z*RXSLVH(`(HJ;C.3:P7@"`"N,]U+DVT-30@`'N;38+L@<VL^
M,(-C;4A"5@@`"4,N-@-M.R@(`%XVDV.**P@`LVJ:*JXV`VOEZ@@`!>6M2UU-
MTVJ[*JXV@VL>Z@@`K4D)0Y-E.R5$4UHK+C.S:@@`"BI^,V-KY>T(``7I`V>N
M,]U+8VV=30@`TVJ[*JXS4VL>Z@@`"4>M0'L@1E<**RXWLVH(`&HJCC<S:^7M
M"``%Z:XWW4LS;9U-"``>ZM-INRD#:WXY8V>M1@@`"4=[)DA7:BLN-[-J"``Z
M*EXWDVOE[0@`!>6N-]U+DVU=30@`'NC39;LE8VM^-3-GC4,(``E'4VU[(TI7
M.BLN-[-J"`":*@XW4VL(``7HKC?EZ@@`K4N3:HU-TV@>[;LH4VM^.)-GW4<(
M`'-@3%<)2H-I+C>K(`@`;C<S:@HJ"`#EY*-F!>I:)FXW@V:M20@`34:39&LD
M<V939]U'3#9S9!"7"4N[)&-M_#=C:W)E+C7W4@@`'C4S80@``.,#H%XQC`*4
M`LP"`V5*)0@`4V>*)WXQY>4(``7G?4T]EUU+TV5`[;LE7C'\/0@`T%TN-H-B
M"4(2+0@`8AU`YC$=_#8S'1[MW4A@5H-A*R'U4OPW\U@N,346"``4%HXT\5$(
M`$86'C`W%@@6PV$Y%@S6;#$28798$FF`.0#H`.D*BPV7?#\F3_9N]FWV;/9K
M]FKV:0L`]F@#V@,*"0"\`M@"\````*C#__\4T17'QB\4W")/##P#`7SD$M(`
MXS$0`.,B(`-A$-)`<3,0`.,B$`_2-1``XR00#M(W$`#C)A`-TCD0`.,H$`#B
M*A`L$`#B.Q`]$"X1)D\+`/9L"0#<Q/__,*T!``$C16>)J\WO_MRZF'94,A#P
MX=+#AB]#QY8O4VBF+V-EMB\`1<8O6C76+V-AYB\(02)//-Q#:1PQ"``,/$I0
M2U0`X@XQ4V,F-`A#8VZ=5YQ6_']BCSPS`>`(``#D#C9.-RL9X^(:&>-A+4$(
M`#LA4V+CXY-M;C&3:SU"'!E^,BT90'W>5$@D+8\X>S_A%SY"C_KCP'[B+SU.
M!N'C:@%Z'4J,.@D`(-*#94#FLV0#`D!X'M,#`Y-DH#CTC\#A%P[R81H.'#X:
MTN-FHV4#`K-D[AT$?R9/]F[V;?9L]FOV:O9I"P#V:$MJ0'KG.A*)$=&3:SA[
MHV:\-`,!@V7>4*PP0(CFCPX=#-*H/JPX`P*39+VO/^'KK^-JU:^#:A8PH(\!
MX)NO"``(K`$`!,+__S[J___FP?__NL'__^;I__^&+TG'EB]#::8O4VBV+\8O
MUB]3;2)/1-PX?0P\6E`(81EA&&M<40E`&&$980%`/\D8:@-D@.$!=!0-..$7
M-!2/2V8ZT4!V`.4#`=PT.-$#`8-DTV`#R`#B8(\XX0[A(B`000>-!'#[KR(@
M,M$X=@#E`P'<-(-A0'&L$;T1+M$#`8-D@F&#9"E!&4$0*8%1@F`=()&`@F`9
M0)*`@F"3@()0*4`90)2`@U&"4!T@E8""4!E`EH""4)>`A%`I0!E`F("%4810
M'2"9@(10&4":@(10FX"&4"E`&4"<@(=1AE`=()V`AE`90)Z`AE"?@!!YB%$I
M01E!$"F)48A0'2`/T9&`B%`90)*`B%`#`9.`)D_V;?9L]FOV:O9I"P#V:"`@
M$$&HC0%P^Z\@(,BJ`0!8Q/__9NG__S#$__\VZ?__-,#__\8O!<<$W`71##P%
MT")/`P'.!R9/"P#V;)BJ`0!VP?__S/___P```````````````,8O!,?F+R)/
M`MSS;@P\`Z`)``D`;*H!``D`"0`)``D`XV\F3_9N]FP+``D``0`"`"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@``
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?
M5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%1%35!$25(`5$U0`%53
M15(`````55-%4DY!344`````)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860`
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`
M````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!P>
M``#('0```0```!P#```!````+`,```$````V`P``#````(`4```-````P%4`
M`!D```#@_@$`&P````0````:````Y/X!`!P````$````!````(P!``#U_O]O
M(`0```4`````"P``!@`````%```*````JP0```L````0````%0`````````#
M````0``"``(```"(`@``%`````<````7````W!$```<```#L$```"````/``
M```)````#````!8`````````'@```!P```#[__]O`0``"/[__V]L$```____
M;P(```#P__]OK`\``/G__V\$````````````````````````````````````
M```````````````````````````````````(``P``@`*4$%2+G!M"@````!`
M60``!````!`````!````1TY5```````#`````@````````#H_@$`````````
M``#P%```#!4``"@5``!$%0``8!4``'P5``"8%0``M!4``-`5``#L%0``"!8`
M`"06``!`%@``7!8``'@6``"4%@``L!8``,P6``#H%@``!!<``"`7```\%P``
M6!<``'07``"0%P``K!<``,@7``#D%P```!@``!P8```X&```5!@``'`8``",
M&```J!@``,08``#@&```_!@``!@9```T&0``4!D``&P9``"(&0``I!D``,`9
M``#<&0``^!D``!0:```P&@``3!H``&@:``"$&@``H!H``+P:````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1&5B:6%N(#$S+C(N,"TQ-BXQ*2`Q,RXR+C```"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YN;W1E
M+D%"22UT86<`+F=O=``N8G-S`"YC;VUM96YT````````````````````````
M```````````````````````````````````+`````0````(```!4`0``5`$`
M`!,```````````````$`````````$P````<````"````:`$``&@!```D````
M```````````$`````````"H````%`````@```(P!``",`0``E`(```4`````
M````!`````0````F````]O__;P(````@!```(`0``.`````%``````````0`
M```$````,`````L````"``````4````%````!@``!@````$````$````$```
M`#@````#`````@`````+````"P``JP0``````````````0````````!`````
M____;P(```"L#P``K`\``,`````%``````````(````"````30```/[__V\"
M````;!```&P0``"`````!@````(````$`````````%P````$`````@```.P0
M``#L$```\`````4`````````!`````P```!F````!````$(```#<$0``W!$`
M`(@"```%````%@````0````,````<`````$````&````@!0``(`4``!,````
M```````````@`````````&L````!````!@```,P4``#,%```!`8`````````
M````!`````0```!V`````0````8```#0&@``T!H``.0Z``````````````0`
M````````?`````$````&````P%4``,!5```L```````````````@````````
M`((````!`````@```.Q5``#L50``UD``````````````!`````````"*````
M`0````(```#$E@``Q)8```0```````````````0`````````E`````X````#
M````X/X!`.#^```$```````````````$````!````*`````/`````P```.3^
M`0#D_@``!```````````````!`````0```"L````!@````,```#H_@$`Z/X`
M`!@!```&``````````0````(````M0````$````#```````"`````0`@````
M```````````$`````````+L````'`````@```"```@`@``$`(```````````
M````!`````````#)`````0````,```!```(`0``!`!@!``````````````0`
M```$````S@````@````#````6`$"`%@!`0`4```````````````$````````
M`-,````!````,`````````!8`0$`(0```````````````0````$````!````
D`P``````````````>0$!`-P```````````````$`````````
